@@ -110,11 +110,22 @@ class AzDataLakeClient(ClientInterface):
             end = min((idx + 1) * upload_unit, data_length)
             split_data = data[start:end]
             # upload data
-            _ = file_client.append_data(data=split_data, offset=start, length=len(split_data))
-        # write date
-        _ = file_client.flush_data(data_length)
+            self.append(path=path, data=split_data, offset=start)
         return True
 
+    def _create(self, path: str) -> dict:
+        file_client = self.get_file_client_from_path(path=path)
+        response = file_client.create_file()
+        return response
+
+    def _append(self, path: str, data, offset: int) -> dict:
+        file_client = self.get_file_client_from_path(path=path)
+        data_length = len(data)
+        response = file_client.append_data(data=data, offset=offset, length=data_length)
+        # write data
+        _ = file_client.flush_data(offset + data_length)
+        return response
+
     def _info(self, path: str):
         return self.get_file_client_from_path(path=path).get_file_properties()
 
